@@ -12,15 +12,22 @@ private:
 	int m_val;
 };
 
+
+volatile int runtime_val = 456;
+CTest global(runtime_val);	// test if global initializers are called.
+
 int main (int argc, char *argv[])
 {
+	assert(global.getVal() == 456);
+
 	auto* t = new CTest(123);
 	assert(t->getVal()!=456);
-    if (argc>1) t->printVal();
+
+	if (argc>1) t->printVal();
 	bool ok = t->getVal() == 123;
 	delete t;
 
-    if (!ok) abort();
+	if (!ok) abort();
 
 	return 0;
 }
